@@ -1,6 +1,6 @@
 package DBIx::Class::Schema::PopulateMore::Inflator;
 
-use Moose;
+use Moo;
 
 =head1 NAME
 
@@ -8,7 +8,7 @@ DBIx::Class::Schema::PopulateMore::Inflator - Base Class for keyword Inflators
 
 =head1 DESCRIPTION
 
-When L<DBIx::Class::Schema::PopulateMore::Command> executes, it uses a vistor object 
+When L<DBIx::Class::Schema::PopulateMore::Command> executes, it uses a visitor object 
 (see L<DBIx::Class::Schema::PopulateMore::Visitor> to descend the key values of the
 data hash that is used to put stuff into the given tables.  If it finds a value
 that matches a particular regexp, that means the value needs to be inflated and
